@@ -20,7 +20,7 @@ def spectral_matrix(dataset, axis):
     """
     if dataset.initial_concentration is None:
         return None, None
-    shape_compartments = [s for s in dataset.shape]
+    shape_compartments = list(dataset.shape)
     compartments = [
         c for c in dataset.initial_concentration.compartments if c in shape_compartments
     ]
