@@ -1,11 +1,26 @@
 """Helper functions."""
+from __future__ import annotations
 
-import typing
+from typing import TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from typing import Any
+    from typing import Callable
+    from typing import TypeVar
+
+    DecoratedFunc = TypeVar("DecoratedFunc", bound=Callable[..., Any])  # decorated function
+
+
+class ModelError(Exception):
+    """Raised when a model contains errors."""
+
+    def __init__(self, error: str):
+        super().__init__(f"ModelError: {error}")
 
 
 def wrap_func_as_method(
-    cls: typing.Any, name: str = None, annotations: str = None, doc: str = None
-) -> typing.Callable:
+    cls: Any, name: str = None, annotations: dict[str, type] = None, doc: str = None
+) -> Callable[[DecoratedFunc], DecoratedFunc]:
     """A decorator to wrap a function as class method.
 
     Notes
@@ -25,7 +40,7 @@ def wrap_func_as_method(
         The documentation of the method. If `None`, the original function's documentation is used.
     """
 
-    def decorator(func):
+    def wrapper(func: DecoratedFunc) -> DecoratedFunc:
         if name:
             func.__name__ = name
         if annotations:
@@ -37,4 +52,4 @@ def wrap_func_as_method(
 
         return func
 
-    return decorator
+    return wrapper
